# GoPro Synchronizer

Tired of *GoPro Cloud* not working?  
Did you miss the old **GoPro software** to sync videos?  
This tool is what you're searching for (if you're a sheel enjoyer)  

## Installation
The tool can be downloaded directly from [PyPi](https://pypi.org/project/gopro-sync/).
```bash
pip install gopro-sync
```

## Usage
You can see the help, `-h`, man to know all the possibile commands.
```bash
gopro-sync -h
```